@@ -247,6 +247,14 @@ def _get_resources_from_list_function(response, method):
         return [x.get('Name') for x in response['Parameters']]
     elif method == 'describe_cache_subnet_groups':
         return [x.get('CacheSubnetGroupName') for x in response['CacheSubnetGroups']]
+    elif method == 'describe_route_tables':
+        return [x.get('RouteTableId') for x in response['RouteTables']]
+    elif method == 'describe_network_acls':
+        return [x.get('NetworkAclId') for x in response['NetworkAcls']]
+    elif method == 'describe_event_subscriptions':
+        return [x.get('EventSubscriptionArn').split(':')[-1] for x in response['EventSubscriptionsList']]
+    elif method == 'describe_db_snapshots':
+        return [x.get('DBSnapshotIdentifier') for x in response['DBSnapshots']]
     else:
         return []
 
@@ -522,6 +530,22 @@ def _get_function_kwargs(arn_str, function_name, existing_json):
         return {
             'FileSystemId': resource_id
         }
+    elif client_str=='ec2'and function_name == 'describe_route_tables':
+        return{
+            'RouteTableIds': [resource_id]
+        }
+    elif client_str=='ec2'and function_name == 'describe_network_acls':
+        return{
+            'NetworkAclIds': [resource_id]
+        }
+    elif client_str=='rds'and function_name == 'describe_event_subscriptions':
+        return{
+            'SubscriptionName': resource_id
+        }
+    elif client_str=='rds'and function_name == 'describe_db_snapshot_attributes':
+        return{
+            'DBSnapshotIdentifier': resource_id
+        }
     else:
         return {}
 
