@@ -1,9 +1,12 @@
 """Mongo db driver and utility functions."""
+import os
 import collections
 from pymongo import MongoClient, TEXT, ASCENDING, DESCENDING
 from pymongo.errors import ServerSelectionTimeoutError
 from bson.objectid import ObjectId
 from processor.helper.config.config_utils import config_value, DATABASE, DBNAME, DBURL
+from processor.logging.dburl_kv import get_dburl
+
 
 
 MONGO = None
@@ -14,12 +17,14 @@ TIMEOUT = 3000
 def mongoconnection(dbport=27017, to=TIMEOUT):
     """ Global connection handle for mongo """
     global MONGO
-    if not MONGO:
-        dburl = config_value(DATABASE, DBURL)
-        if dburl:
-            MONGO = MongoClient(host=dburl, serverSelectionTimeoutMS=to)
-        else:
-            MONGO = MongoClient(port=dbport, serverSelectionTimeoutMS=to)
+    if MONGO:
+        return MONGO
+    dburl = get_dburl()
+    # os.getenv(DBURL, None)
+    if dburl:
+        MONGO = MongoClient(host=dburl, serverSelectionTimeoutMS=to)
+    else:
+        MONGO = MongoClient(port=dbport, serverSelectionTimeoutMS=to)
     return MONGO
 
 
