@@ -1,5 +1,4 @@
 """Helper functions to setup logging for the framework."""
-import datetime
 import logging
 from logging.handlers import RotatingFileHandler
 import datetime
@@ -8,7 +7,8 @@ import os
 from pymongo import MongoClient
 from pymongo.errors import ServerSelectionTimeoutError
 from processor.helper.config.config_utils import framework_dir,\
-    get_config_data, framework_config, TESTS, DBVALUES, NONE, config_value
+    get_config_data, framework_config, DBVALUES, NONE
+from processor.logging.dburl_kv import get_dburl
 
 
 FWLOGGER = None
@@ -18,7 +18,6 @@ DBLOGGER = None
 dbhandler = None
 
 
-
 class MongoDBHandler(logging.Handler):
     """Customized logging handler that puts logs to the database, pymongo required
     """
@@ -44,7 +43,9 @@ class MongoDBHandler(logging.Handler):
 
     def set_log_collection(self):
         global DBLOGGER
-        log_name = 'logs_%s' % datetime.datetime.now().strftime('%Y%m%d%H%M%S')
+        log_name = os.getenv('LOGNAME', None)
+        if not log_name:
+            log_name = 'logs_%s' % datetime.datetime.now().strftime('%Y%m%d%H%M%S')
         coll = self.db[self.coll_name]
         self.collection = coll
         DBLOGGER = log_name
@@ -93,6 +94,7 @@ def logging_fw(fwconfigfile, dbargs):
         "backups": 10,
         "db": None
     }
+    unittest = os.getenv('UNITTEST', "false")
     if fw_cfg and 'LOGGING' in fw_cfg:
         fwconf = fw_cfg['LOGGING']
         # log_config['level'] = logging.getLevelName(fwconf['level']) \
@@ -105,7 +107,7 @@ def logging_fw(fwconfigfile, dbargs):
         log_config['propagate'] = fwconf.getboolean('propagate') if 'propagate' in fwconf \
             else True
         log_config['db'] = fwconf['dbname'] if 'dbname' in fwconf else None
-        log_config['dburl'] = fw_cfg['MONGODB']['dburl'] if 'dbname' in fwconf else None
+        log_config['dburl'] = get_dburl() if 'dbname' in fwconf and unittest != "true" else None
     level = os.getenv('LOGLEVEL', None)
     loglevel = level if level and level in ['CRITICAL', 'ERROR', 'WARNING', 'INFO', 'DEBUG'] \
         else log_config['level']
@@ -127,7 +129,7 @@ def logging_fw(fwconfigfile, dbargs):
     # handler.setLevel(log_config['level'])
     handler.setLevel(loglevel)
     logger.addHandler(handler)
-    unittest = os.getenv('UNITTEST', "false")
+    # print(log_config)
     if log_config['db'] and unittest != "true" and dbargs:
         dblogformat = '%(asctime)s-%(message)s'
         dbhandler = MongoDBHandler(log_config['dburl'], log_config['db'])
